@@ -410,14 +410,12 @@ class Serial(SerialBase):
         if self.is_open:
             raise SerialException("Port is already open.")
         try:
-            self._socket = socket.create_connection(self.from_url(self.portstr))
+            self._socket = socket.create_connection(self.from_url(self.portstr), timeout=5)  # XXX good value?
             self._socket.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
         except Exception as msg:
             self._socket = None
             raise SerialException("Could not open port {}: {}".format(self.portstr, msg))
 
-        self._socket.settimeout(5)  # XXX good value?
-
         # use a thread save queue as buffer. it also simplifies implementing
         # the read timeout
         self._read_buffer = Queue.Queue()
@@ -583,15 +581,13 @@ class Serial(SerialBase):
                     self._network_timeout = float(values[0])
                 else:
                     raise ValueError('unknown option: {!r}'.format(option))
-            # get host and port
-            host, port = parts.hostname, parts.port
-            if not 0 <= port < 65536:
+            if not 0 <= parts.port < 65536:
                 raise ValueError("port not in range 0...65535")
         except ValueError as e:
             raise SerialException(
                 'expected a string in the form '
                 '"rfc2217://<host>:<port>[?option[&option...]]": {}'.format(e))
-        return (host, port)
+        return (parts.hostname, parts.port)
 
     #  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -
 
